@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Combinatorial algorithms to generate rhythms
 
-our $VERSION = '0.0403';
+our $VERSION = '0.0404';
 
 use Moo;
 use strictures 2;
@@ -230,7 +230,7 @@ sub euclid {
 }
 
 
-sub interval2seq {
+sub int2b {
     my ($self, $intervals) = @_;
     my @sequences;
     for my $i (@$intervals) {
@@ -505,7 +505,7 @@ sub _allowed { # is p one of the parts?
 }
 
 
-sub seq2interval {
+sub b2int {
     my ($self, $sequences) = @_;
     my @intervals;
     for my $i (@$sequences) {
@@ -529,7 +529,7 @@ Music::CreatingRhythms - Combinatorial algorithms to generate rhythms
 
 =head1 VERSION
 
-version 0.0403
+version 0.0404
 
 =head1 SYNOPSIS
 
@@ -682,17 +682,17 @@ Examples:
   $got = $mcr->euclid(3, 4); # [1,1,0,1]
   $got = $mcr->euclid(4, 4); # [1,1,1,1]
 
-=head2 interval2seq
+=head2 int2b
 
-  $sequences = $mcr->interval2seq($intervals);
+  $sequences = $mcr->int2b($intervals);
 
 Convert B<intervals> of the form C<[2,3]> into a set of binary
 sequences.
 
 Examples:
 
-  $got = $mcr->interval2seq([[1,2,3]]);     # [[1,1,0,1,0,0]]
-  $got = $mcr->interval2seq([[1],[2],[3]]); # [[1],[1,0],[1,0,0]]
+  $got = $mcr->int2b([[1,2,3]]);     # [[1,1,0,1,0,0]]
+  $got = $mcr->int2b([[1],[2],[3]]); # [[1],[1,0],[1,0,0]]
 
 =head2 invert_at
 
@@ -869,17 +869,17 @@ Examples:
   $got = $mcr->rotate_n(4, $parts); # 0 1 0 0 1
   $got = $mcr->rotate_n(5, $parts); # 1 0 1 0 0
 
-=head2 seq2interval
+=head2 b2int
 
-  $intervals = $mcr->seq2interval($sequences);
+  $intervals = $mcr->b2int($sequences);
 
 Convert binary B<sequences> of the form C<[[1,0],[1,0,0]]> into a set
 of intervals of the form C<[[2],[3]]>.
 
 Examples:
 
-  $got = $mcr->seq2interval([[1,1,0,1,0,0]]);     # [[1,2,3]]
-  $got = $mcr->seq2interval([[1],[1,0],[1,0,0]]); # [[1],[2],[3]]
+  $got = $mcr->b2int([[1,1,0,1,0,0]]);     # [[1,2,3]]
+  $got = $mcr->b2int([[1],[1,0],[1,0,0]]); # [[1],[2],[3]]
 
 =head1 SEE ALSO
 
